﻿using System;
using Microsoft.EntityFrameworkCore.Internal;

namespace StudentMonitoring.Persistence
{
    public static class DbInitializer
    {
        public static void Initialize(MonitoringContext context)
        {
            context.Database.EnsureCreated();

            if (context.Students.Any())
                return;

            var students = new Student[]
            {
                new Student {StudentCode = "KISJAN", Name = "Kiss János", EmailAddress = "jani@ote.op"},
                new Student {StudentCode = "NAGJAN", Name = "Nagy János", EmailAddress = "jani2@ote.op"},
                new Student {StudentCode = "RUGPAL", Name = "Rúgka Pál", EmailAddress = "pali@ote.op"},
                new Student {StudentCode = "BARARO", Name = "Bármi Áron", EmailAddress = "aron@ote.op"},
                new Student {StudentCode = "VIRDOR", Name = "Virra Dóra", EmailAddress = "dori@ote.op"},
                new Student {StudentCode = "BATMAN", Name = "Bruce Wayne", EmailAddress = "darkknight@gotham.com"}
            };
            context.Students.AddRange(students);

            var courses = new Course[]
            {
                new Course {CourseCode = "OTE-ARVA2G", Name = "Arab varázslás 2. GY"},
                new Course {CourseCode = "OTE-IDO1E", Name = "Időutazás 1. EA"},
                new Course {CourseCode = "OTE-IDO2E", Name = "Időutazás 2. EA"},
                new Course {CourseCode = "OTE-OPTUVIKUE", Name = "Óperencián túli világok kultúrája EA"},
                new Course {CourseCode = "OTE-PAFOG", Name = "Pálinkafőzés GY"}
            };
            context.Courses.AddRange(courses);

            var marks = new Mark[]
            {
                new Mark() { Student = students[0], Course = courses[0], Grade = 1, Timestamp = new DateTime(2019, 12, 10)},
                new Mark() { Student = students[0], Course = courses[0], Grade = 1, Timestamp = new DateTime(2019, 7, 8)},
                new Mark() { Student = students[0], Course = courses[2], Grade = 3, Timestamp = new DateTime(2019, 7, 9)},
                new Mark() { Student = students[0], Course = courses[2], Grade = 1, Timestamp = new DateTime(2019, 1, 20)},
                new Mark() { Student = students[0], Course = courses[3], Grade = 5, Timestamp = new DateTime(2019, 12, 11)},
                new Mark() { Student = students[0], Course = courses[3], Grade = 1, Timestamp = new DateTime(2018, 12, 3)},
                new Mark() { Student = students[0], Course = courses[4], Grade = 2, Timestamp = new DateTime(2019, 12, 2)},

                new Mark() { Student = students[1], Course = courses[0], Grade = 4, Timestamp = new DateTime(2019, 12, 10)},
                new Mark() { Student = students[1], Course = courses[0], Grade = 1, Timestamp = new DateTime(2019, 12, 8)},
                new Mark() { Student = students[1], Course = courses[1], Grade = 2, Timestamp = new DateTime(2019, 12, 1)},
                new Mark() { Student = students[1], Course = courses[1], Grade = 1, Timestamp = new DateTime(2018, 11, 30)},
                new Mark() { Student = students[1], Course = courses[2], Grade = 5, Timestamp = new DateTime(2019, 12, 1)},
                new Mark() { Student = students[1], Course = courses[2], Grade = 1, Timestamp = new DateTime(2018, 12, 1)},
                new Mark() { Student = students[1], Course = courses[2], Grade = 1, Timestamp = new DateTime(2017, 12, 1)},

                new Mark() { Student = students[2], Course = courses[0], Grade = 1, Timestamp = new DateTime(2019, 12, 6)},
                new Mark() { Student = students[2], Course = courses[0], Grade = 1, Timestamp = new DateTime(2019, 11, 30)},
                new Mark() { Student = students[2], Course = courses[1], Grade = 1, Timestamp = new DateTime(2019, 1, 29)},
                new Mark() { Student = students[2], Course = courses[1], Grade = 1, Timestamp = new DateTime(2018, 12, 6)},
                new Mark() { Student = students[2], Course = courses[2], Grade = 1, Timestamp = new DateTime(2019, 12, 11)},

                new Mark() { Student = students[3], Course = courses[1], Grade = 4, Timestamp = new DateTime(2019, 1, 6)},
                new Mark() { Student = students[3], Course = courses[1], Grade = 1, Timestamp = new DateTime(2018, 1, 21)},
                new Mark() { Student = students[3], Course = courses[2], Grade = 1, Timestamp = new DateTime(2019, 12, 1)},
                new Mark() { Student = students[3], Course = courses[2], Grade = 1, Timestamp = new DateTime(2018, 12, 7)},
                new Mark() { Student = students[3], Course = courses[3], Grade = 1, Timestamp = new DateTime(2018, 11, 11)},

                new Mark() { Student = students[4], Course = courses[4], Grade = 5, Timestamp = new DateTime(2019, 12, 4)},
                new Mark() { Student = students[4], Course = courses[3], Grade = 3, Timestamp = new DateTime(2019, 12, 18)},
                new Mark() { Student = students[4], Course = courses[3], Grade = 1, Timestamp = new DateTime(2019, 12, 1)},

                new Mark() { Student = students[5], Course = courses[0], Grade = 5, Timestamp = new DateTime(2019, 12, 19)},
                new Mark() { Student = students[5], Course = courses[1], Grade = 5, Timestamp = new DateTime(2019, 12, 19)},
                new Mark() { Student = students[5], Course = courses[2], Grade = 5, Timestamp = new DateTime(2019, 12, 19)},
                new Mark() { Student = students[5], Course = courses[3], Grade = 5, Timestamp = new DateTime(2018, 12, 19)},
                new Mark() { Student = students[5], Course = courses[4], Grade = 5, Timestamp = new DateTime(2019, 12, 19)},
            };
            context.Marks.AddRange(marks);

            context.SaveChanges();
        }
    }
}
